@@ -196,6 +196,14 @@ GBD = Instruction(
             Argument('location', PTR),
         ]
     )
+
+RET = Instruction(
+        'RET',
+        0x14,
+        [
+        ]
+    )
+
 instructions = {
         0x00: POK,
         0x01: LON,
@@ -217,4 +225,5 @@ instructions = {
         0x11: SCF,
         0x12: SBB,
         0x13: GBD,
+        0x14: RET
 }
